Module breakpoint

Module breakpoint 

Software breakpoint installation and management.

Structs

Manager
Breakpoint manager that owns breakpoint metadata for a traced process.
Pending
Represents a breakpoint event that needs to be processed by the tracer.