pub struct Pending { /* private fields */ }Expand description
Represents a breakpoint event that needs to be processed by the tracer.
When a permanent breakpoint is hit we return a Pending value containing
the breakpoint id (if assigned) and the address where it was hit. This
allows the tracer to re-install or re-register the breakpoint as needed.
Implementations