ptrace-based command handler functions for the debugger REPL.
Functions
- do_
ambiguous - Handler for ambiguous commands (user input matches multiple commands).
- do_
backtrace - Handler that prints a backtrace for the traced process.
- do_
breakpoint - Set a permanent breakpoint at the given address or the previous RIP.
- do_
continue - Continue execution of the traced process.
- do_
delete - Delete a breakpoint by id.
- do_
examine - Examine memory at a given address and format the bytes.
- do_help
- Print help text for available commands.
- do_
info_ breakpoints - Print information about currently set breakpoints.
- do_
info_ memory - Print the memory map (
/proc/PID/maps) of the traced process. - do_
info_ registers - Print the current register state of the traced process.
- do_
invalid_ arguments - Handler for invalid argument errors.
- do_
layout_ asm - Switch the display layout to assembly mode.
- do_
layout_ src - Switch the display layout to source mode (when available).
- do_list
- Re-print the last printed source or assembly chunk.
- do_next
- Step over the next instruction (implement stepping semantics).
- do_
nothing - A no-op handler that does nothing and stalls execution.
- do_quit
- Quit the debugger and exit the tracer loop.
- do_step
- Step a single instruction (single-step execution).
- do_
tbreakpoint - Set a temporary breakpoint at the given address or previous RIP.
- do_
unknown - Handler for completely unknown commands.
Type Aliases
- Command
Fn - Type of a command handler function.