do_backtrace

Function do_backtrace 

pub fn do_backtrace(args: &[Value<'_>], state: &mut State<'_>) -> Result<()>
Handler that prints a backtrace for the traced process.

Uses libunwind via ptrace to walk the tracee’s stack and prints each frame. When DWARF line information is available it will include file and line information.

Errors

Returns an error if libunwind/ptrace operations fail or if address -> line resolution fails.