do_breakpoint

Function do_breakpoint 

pub fn do_breakpoint(args: &[Value<'_>], state: &mut State<'_>) -> Result<()>
Set a permanent breakpoint at the given address or the previous RIP.

Errors

Returns an error if argument parsing fails or if setting the breakpoint via the breakpoint manager fails.