do_examine

Function do_examine 

pub fn do_examine(args: &[Value<'_>], state: &mut State<'_>) -> Result<()>
Examine memory at a given address and format the bytes.

Errors

Returns an error if arguments are invalid, memory cannot be read, or formatting fails.