do_info_registers

Function do_info_registers 

pub fn do_info_registers(
    args: &[Value<'_>],
    state: &mut State<'_>,
) -> Result<()>
Print the current register state of the traced process.

Errors

Returns an error if reading registers via ptrace fails.