do_tbreakpoint

Function do_tbreakpoint 

pub fn do_tbreakpoint(args: &[Value<'_>], state: &mut State<'_>) -> Result<()>
Set a temporary breakpoint at the given address or previous RIP.

Temporary breakpoints are removed after they are hit.

Errors

Returns an error if argument parsing or breakpoint insertion fails.