CommandFn

Type Alias CommandFn 

pub type CommandFn = fn(&[Value<'_>], &mut State<'_>) -> Result<()>;
Type of a command handler function.

A CommandFn is a function that receives the parsed argument list and a mutable reference to the current progress::State and returns a Result indicating success or failure.