Module param

Module param 

Command parameter types and parsed value representation.

Enums

Format
How to format bytes when examining memory.
Type
The expected parameter type for a command argument.
Value
A parsed command argument value.

Traits

Extend
Helpers to extend a parsed Value path with additional string arguments.
Join
Join a slice of Value into a single String using sep as separator.