Module profile

Module profile 

Instruction-level profiling tracer.

Structs

Tracer
Holds resources needed to parse and trace a target binary.

Functions

trace_with
Traces the execution of a process and prints the instructions being executed.
trace_with_default_print
Convenience wrapper around trace_with that uses the default print and progress callbacks.