pub enum Type {
Int,
Ptr,
Str,
Uint,
}Expand description
Representation of a syscall argument or return value type.
This enum describes how a syscall argument or return value should be interpreted when pretty-printing traced syscalls (signed integer, pointer, string, or unsigned integer).
Variants
Int
Signed integer value (printed as i64).
Ptr
Pointer value (printed as NULL or hex address).
Str
NUL-terminated string located in the traced process memory.
Uint
Unsigned integer value.