Pending

Struct Pending 

pub struct Pending { /* private fields */ }
Represents a breakpoint event that needs to be processed by the tracer.

When a permanent breakpoint is hit we return a Pending value containing the breakpoint id (if assigned) and the address where it was hit. This allows the tracer to re-install or re-register the breakpoint as needed.

Implementations

Source

impl Pending

pub fn new(id: Option<u64>, address: u64) -> Self

Create a new Pending event.

Arguments
  • id - Optional breakpoint id assigned by the manager.
  • address - Address where the breakpoint was hit.
Returns

A newly-created Pending event.

pub fn id(&self) -> Option<u64>

Return the optional breakpoint id associated with this pending event.

Returns

The optional breakpoint id assigned by the manager, or None if the breakpoint was not registered.

pub fn address(&self) -> u64

Return the address where the breakpoint was hit.

Returns

The instruction address where the breakpoint occurred.