pub fn do_breakpoint(args: &[Value<'_>], state: &mut State<'_>) -> Result<()>Expand description
Set a permanent breakpoint at the given address or the previous RIP.
Errors
Returns an error if argument parsing fails or if setting the breakpoint via the breakpoint manager fails.