pub fn do_examine(args: &[Value<'_>], state: &mut State<'_>) -> Result<()>
Examine memory at a given address and format the bytes.
Returns an error if arguments are invalid, memory cannot be read, or formatting fails.