pub fn env() -> Result<Vec<CString>>Expand description
Retrieves environment variables and returns them as a vector of CString.
Arguments
This function does not take parameters; it reads the current process environment.
Errors
This function will return an Err if there is an error converting environment variables to CString.
Returns
Returns a vector of CString representing the environment variables.