pub trait Join {
// Required method
fn join(&self, sep: &str) -> String;
}Expand description
Join a slice of Value into a single String using sep as separator.
This is a convenience used by handlers when composing user-visible
messages from an array of previously parsed Value arguments.