Instruction-level profiling tracer.
Structs
- Tracer
- Holds resources needed to parse and trace a target binary.
Functions
- trace_
with - Traces the execution of a process and prints the instructions being executed.
- trace_
with_ default_ print - Convenience wrapper around
trace_withthat uses the default print and progress callbacks.