pub struct State<'a> { /* private fields */ }Expand description
Runtime state shared with progress callbacks and handlers.
Implementations
Sourceimpl<'a> State<'a>
impl<'a> State<'a>
Sourcepub fn initial_layout(&self) -> Layout
pub fn initial_layout(&self) -> Layout
Return the initial layout computed from available DWARF.
Returns
The initial Layout chosen based on whether DWARF is available.
Sourcepub fn set_layout(&mut self, layout: Layout)
pub fn set_layout(&mut self, layout: Layout)
Sourcepub fn set_requested_layout(&mut self, layout: Layout)
pub fn set_requested_layout(&mut self, layout: Layout)
Request a new layout which will be applied by the tracer loop.
Arguments
layout- The requestedLayoutwhich will be applied asynchronously by the tracer loop.
Sourcepub fn take_requested_layout(&mut self) -> Option<Layout>
pub fn take_requested_layout(&mut self) -> Option<Layout>
Take and return any requested layout.
Returns
Some(Layout) when a layout was requested, otherwise None.
Sourcepub fn breakpoint_mgr(&mut self) -> &mut Manager
pub fn breakpoint_mgr(&mut self) -> &mut Manager
Mutable access to the breakpoint manager owned by the state.
Returns
A mutable reference to the internal breakpoint::Manager.
Sourcepub fn print_breakpoints(&self)
pub fn print_breakpoints(&self)
Print the currently registered breakpoints to stdout.
This function writes the breakpoint manager’s display representation to stdout.
Sourcepub fn set_prev_rip(&mut self, rip: u64)
pub fn set_prev_rip(&mut self, rip: u64)
Sourcepub fn set_printed(&mut self, printed: Option<String>)
pub fn set_printed(&mut self, printed: Option<String>)
Sourcepub fn execution(&self) -> &Execution
pub fn execution(&self) -> &Execution
Return the current execution state.
Returns
A reference to the Execution enum representing the current execution state.
Sourcepub fn set_execution(&mut self, execution: Execution)
pub fn set_execution(&mut self, execution: Execution)